@@ -662,8 +662,8 @@ void Plotter3D::addPlots(PlotItem* item)
         glGenBuffers(1, &m_itemGeometries[item].second);
         glBindBuffer(GL_ARRAY_BUFFER, m_itemGeometries[item].second);
         glBufferData(GL_ARRAY_BUFFER, 3*sizeof(float)*surf->vertices().size() + 3*sizeof(float)*surf->normals().size(), 0, GL_STREAM_DRAW);
-        glBufferSubData(GL_ARRAY_BUFFER, 0, 3*sizeof(float)*surf->vertices().size(), surf->vertices().data());
-        glBufferSubData(GL_ARRAY_BUFFER, 3*sizeof(float)*surf->vertices().size(), 3*sizeof(float)*surf->normals().size(), surf->normals().data());
+        glBufferSubData(GL_ARRAY_BUFFER, 0, 3*sizeof(float)*surf->vertices().size(), surf->vertices().constData());
+        glBufferSubData(GL_ARRAY_BUFFER, 3*sizeof(float)*surf->vertices().size(), 3*sizeof(float)*surf->normals().size(), surf->normals().constData());
         //TODO ifdef debug_Graph
         //glGetBufferParameteriv(GL_ARRAY_BUFFER, GL_BUFFER_SIZE, &bufferSize);
         //qDebug() << "Vertex Array in VBO: " << bufferSize << " bytes";
@@ -671,7 +671,7 @@ void Plotter3D::addPlots(PlotItem* item)
         //indices
         glGenBuffers(1, &m_itemGeometries[item].first);
         glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_itemGeometries[item].first);
-        glBufferData(GL_ELEMENT_ARRAY_BUFFER, sizeof(unsigned int)*surf->indexes().size(), surf->indexes().data(), GL_STATIC_DRAW);
+        glBufferData(GL_ELEMENT_ARRAY_BUFFER, sizeof(unsigned int)*surf->indexes().size(), surf->indexes().constData(), GL_STATIC_DRAW);
         //glGetBufferParameteriv(GL_ELEMENT_ARRAY_BUFFER, GL_BUFFER_SIZE, &bufferSize);
         //qDebug() << "Index Array in VBO: " << bufferSize << " bytes";
 
